@@ -1,4 +1,5 @@
 import ctypes
 
-def bpf_ktime_get_ns():
+
+def ktime():
     return ctypes.c_int64(0)
